# react-redux-internet-connection
Check internet connection from your redux's state

### Installation
npm:
```bash
npm install react-redux-internet-connection
```

yarn:
```bash
yarn add react-redux-internet-connection
```

### Config

In your main reducers
```js
import { combineReducers } from 'redux';
import { reducer as internet } from 'react-redux-internet-connection';

const rootReducer = combineReducers({
  internet
});
export default rootReducer;

```

And you just need to add `ReactReduxInternetConnection` in App.js
```js
import React, { PureComponent } from 'react';
import { ReactReduxInternetConnection } from 'react-redux-internet-connection';

class App extends PureComponent {

  render() {
    return (
      <div className="App">
        <h1>react-internet-connection</h1>
        <ReactReduxInternetConnection />
      </div>
    );
  }
}

export default App;

```

### Usage

```js
import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';

// you can access in every where to internet connection :)
@connect(state => ({
  connection: state.internet.connection
}), { })

export default class Home extends PureComponent {
  static propTypes = {
    connection: PropTypes.bool,
  };

  render() {
    const { connection } = this.props;
    return (
      <div>
        {connection &&
        <h1>connected :)</h1>}
        {!connection &&
        <h1>disconnected :(</h1>}
      </div>
    );
  }
}

```